translate.storage.xml_extract

Package translate :: Package storage :: Package xml_extract |
[hide private]
[frames] | no frames]

# Package xml_extract

source code

Submodules | [hide private]
translate.storage.xml_extract.extract translate.storage.xml_extract.generate translate.storage.xml_extract.misc translate.storage.xml_extract.unit_tree translate.storage.xml_extract.xpath_breadcrumb

Variables | [hide private]
| __package__ = `None` hash(x)

Imports: misc